@@ -4,7 +4,8 @@ from .algorithms.diff_engine import DiffEngine
 from .algorithms import segment_matcher, SegmentMatcher
 from .algorithms import sequence_matcher, SequenceMatcher
 from .tokenizers import (Token, Tokenizer, RegexTokenizer, text_split,
-                         wikitext_split)
+                         wikitext_split, wikitext_split_w_cjk,
+                         cjk_tokenization, lexicon)
 from .segmenters import (Segmenter, Segment, MatchableSegment,
                          ParagraphsSentencesAndWhitespace)
 
@@ -17,7 +18,7 @@ __all__ = [apply,
            segment_matcher, SegmentMatcher,
            sequence_matcher, SequenceMatcher,
            Token, Tokenizer, RegexTokenizer, text_split, wikitext_split,
-           Segmenter, Segment, MatchableSegment,
-           ParagraphsSentencesAndWhitespace,
+           wikitext_split_w_cjk, cjk_tokenization, lexicon, Segmenter,
+           Segment, MatchableSegment, ParagraphsSentencesAndWhitespace,
            __name__, __version__, __author__, __author_email__,
            __description__, __license__, __url__]
